/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {
dojo.provide("com.ibm.team.process.web.ui.internal.admin.projects.ManageArchivedProjectAreas");

dojo.require("dojox.data.dom");

dojo.require("net.jazz.ajax.ui.PlatformUI");

dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");

dojo.require("com.ibm.team.process.web.client.projectarea");
dojo.require("com.ibm.team.repository.web.ui.internal.admin.ItemList");
dojo.require("com.ibm.team.process.web.client.internal.ProcessClient");

var ProcessClient = com.ibm.team.process.web.client.internal.ProcessClient;
var ServiceResponseHandler = com.ibm.team.repository.web.transport.ServiceResponseHandler;

function setText(e, text){
	e.appendChild(document.createTextNode(text));
}

var PROJECT_ACTION_PREFIX = "com.ibm.team.process.editArchivedProjectArea&itemId=";

dojo.declare("com.ibm.team.process.web.ui.internal.admin.projects.ManageArchivedProjectAreas", com.ibm.team.repository.web.ui.internal.admin.ItemList, {
	
	postCreate: function() {
		setText(this.heading, "Archived Project Areas");
		setText(this.description, "Use this interface to manage archived project areas.  To edit a project area, click the appropriate row in the table below.");
		this.tableHeading.parentNode.removeChild(this.tableHeading);
		this.newItemButtonArea.parentNode.removeChild(this.newItemButtonArea);
		this.setHeaderRow(["Name", "Description"]);
		this.headerRow.cells[0].style.width = "30%";
		this.refresh();
	},
	
	refresh: function () {
		this.clearState();
		var tr = document.createElement("tr");
		var td = document.createElement("td");
		td.colSpan = 2;
		td.appendChild(document.createTextNode("Loading..."));
		tr.appendChild(td);
		this.tbody.appendChild(tr);
		var srh = new ServiceResponseHandler(this, "showProjects", "handleError");
		ProcessClient.getAllProjectAreas(srh, { onlyArchivedProjects: true });
	},
	
	clearState: function () {
		dojox.data.dom.removeChildren(this.tbody);
		dojox.data.dom.removeChildren(this.messageDiv);
		dojox.data.dom.removeChildren(this.messageBox);
		this.messageBox.className = "";
	},
	
	showProjects: function(data) {
		dojox.data.dom.removeChildren(this.tbody);
		if (data != null) {
			var sortedData = data.sort(function (a,b) {
				return a.name > b.name ? 1 : a.name < b.name ? -1 : 0;
			});
			for (var i=0; i < sortedData.length; i++) {
				var actionHref = PROJECT_ACTION_PREFIX + sortedData[i].itemId;
				var span = document.createElement("span");
				span.appendChild(document.createTextNode(sortedData[i].summary));
				if (sortedData[i].description) {
					span.appendChild(document.createElement("br"));
					span.appendChild(document.createElement("br"));
					span.appendChild(document.createTextNode(sortedData[i].description));
				}
				var row = this.addRow(actionHref, [sortedData[i].name, span]);
				if (i === 0) {
					dojo.toggleClass(row.parentNode,"projectTable",true);
				}
			}
		}
		else {
			this.messageDiv.appendChild(document.createTextNode("No archived project areas exist"));
		}
	}
});

})();