/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
dojo.provide("com.ibm.team.process.web.ui.internal.admin.projects.ProcessRoleDialog");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("dijit.form.Button");
dojo.require("dijit.form.TextBox");
dojo.require("dojox.data.dom");

(function() {
	
function getSelectedIndices(list) {
	var selected = new Array();
	for (var i=0; i < list.options.length; i++) {
		if (list.options[i].selected) {
			selected.push(i);
		}
	}
	return selected;
}
	
dojo.declare("com.ibm.team.process.web.ui.internal.admin.projects.ProcessRoleDialog", [dijit._Widget, dijit._Templated], {
		
	templatePath: dojo.moduleUrl("com.ibm.team.process.web", "ui/internal/admin/projects/templates/ProcessRoleDialog.html"),
	widgetsInTemplate: true,
	
	constructor: function (args) {
		this.allRoles = args.allRoles;
		this.member = args.member;
	},
	
	postCreate: function () {
		this.availableRoles.opposite = this.selectedRoles;
		this.selectedRoles.opposite = this.availableRoles;
		this.populateObj();
		this.connect(this.availableRoles, "onchange", "handleListChange");
		this.connect(this.selectedRoles, "onchange", "handleListChange");
		this.connect(this.addButton, "onclick", "handleAdd");
		this.connect(this.removeButton, "onclick", "handleRemove");
		this.connect(this.upButton, "onclick", "handleUp");
		this.connect(this.downButton, "onclick", "handleDown");
		this.updateButtonState();
	},
	
	repopulate: function (data) {
		this.allRoles = data.allRoles;
		this.member = data.member;
		this.populateObj();
	},
	
	populateObj: function () {
		dojox.data.dom.removeChildren(this.userNameSpan);
		dojox.data.dom.removeChildren(this.availableRoles);
		dojox.data.dom.removeChildren(this.selectedRoles);
		this.userNameSpan.appendChild(document.createTextNode(this.member.name));
		this.selectedRoleMap = new Object();
		for (var i=0; i < this.member.processRoles.length; i++) {
			this.selectedRoleMap[this.member.processRoles[i].id] = true;
			var option = document.createElement("option");
			option.value = this.member.processRoles[i].id;
			if (this.member.processRoles[i].id == "default") {
				option.appendChild(document.createTextNode(this.member.processRoles[i].id + " [unmodifiable]"));
				option.frozen = true;
			}
			else {
				option.appendChild(document.createTextNode(this.member.processRoles[i].id));
			}
			option.description = this.member.processRoles[i].description;
			this.selectedRoles.appendChild(option);
		}
		for (var i=0; i < this.allRoles.length; i++) {
			if (this.selectedRoleMap[this.allRoles[i].id]) {
				continue;
			}
			var option = document.createElement("option");
			option.value = this.allRoles[i].id;
			option.appendChild(document.createTextNode(this.allRoles[i].id));
			option.description = this.allRoles[i].description;
			this.availableRoles.appendChild(option);
		}
	},
	
	handleListChange: function (e) {
		for (var i=0; i < e.target.opposite.options.length; i++) {
			e.target.opposite.options[i].selected = false;
		}
		this.updateButtonState();
		var selectedItems = getSelectedIndices(e.target);
		dojox.data.dom.removeChildren(this.description);
		if (selectedItems.length == 1) {
			this.description.appendChild(document.createTextNode(e.target.options[selectedItems[0]].description));
		}
	},
	
	handleAdd: function (e) {
		dojo.stopEvent(e);
		if (dojo.isIE && dojo.isIE > 6) {
			this.selectedRoles.style.display = "none";	
		}
		var indices = getSelectedIndices(this.availableRoles);
		for (var i=indices.length - 1; i >= 0; i--) {
			if (dojo.isIE && dojo.isIE < 7) {
				// IE6 doesn't handle removeChild and insertBefore well for select lists
				// Do things the old-fashioned way
				var option = this.availableRoles.options[indices[i]];
				var opt = option;
				for (var j=indices[i]; j < this.availableRoles.options.length - 1; j++) {
					var curOpt = this.availableRoles.options[j+1];
					var newOpt = new Option(curOpt.text, curOpt.value);
					newOpt.description = curOpt.description;
					newOpt.frozen = curOpt.frozen;
					this.availableRoles.options[j] = newOpt;
				}
				this.availableRoles.options.length = this.availableRoles.options.length - 1;
				
				option = new Option(opt.text, opt.value);
				option.description = opt.description;
				option.frozen = opt.frozen;
				for (var j=this.selectedRoles.options.length; j > 0; j--) {
					var curOpt = this.selectedRoles.options[j-1];
					var newOpt = new Option(curOpt.text, curOpt.value);
					newOpt.description = curOpt.description;
					newOpt.frozen = curOpt.frozen;
					this.selectedRoles.options[j] = newOpt;
				}
				this.selectedRoles.options[0] = option;
			}
			else {
				var option = this.availableRoles.options[indices[i]];
				this.availableRoles.removeChild(option);
				this.selectedRoles.insertBefore(option, this.selectedRoles.options[0]);
			}
		}
		this.updateButtonState();
		if (dojo.isIE) {
			this.selectedRoles.style.display = "block";	
		}
	},
	
	handleRemove: function (e) {
		dojo.stopEvent(e);
		if (dojo.isIE && dojo.isIE > 6) {
			this.availableRoles.style.display = "none";	
		}
		var indices = getSelectedIndices(this.selectedRoles);
		for (var i=indices.length - 1; i >= 0; i--) {
			if (dojo.isIE && dojo.isIE < 7) {
				// IE6 doesn't handle removeChild and insertBefore well for select lists
				// Do things the old-fashioned way
				var option = this.selectedRoles.options[indices[i]];
				var opt = option;
				for (var j=indices[i]; j < this.selectedRoles.options.length - 1; j++) {
					var curOpt = this.selectedRoles.options[j+1];
					var newOpt = new Option(curOpt.text, curOpt.value);
					newOpt.description = curOpt.description;
					newOpt.frozen = curOpt.frozen;
					this.selectedRoles.options[j] = newOpt;
				}
				this.selectedRoles.options.length = this.selectedRoles.options.length - 1;
				
				option = new Option(opt.text, opt.value);
				option.description = opt.description;
				option.frozen = opt.frozen;
				for (var j=this.availableRoles.options.length; j > 0; j--) {
					var curOpt = this.availableRoles.options[j-1];
					var newOpt = new Option(curOpt.text, curOpt.value);
					newOpt.description = curOpt.description;
					newOpt.frozen = curOpt.frozen;
					this.availableRoles.options[j] = newOpt;
				}
				this.availableRoles.options[0] = option;
			}
			else {
				var option = this.selectedRoles.options[indices[i]];
				this.selectedRoles.removeChild(this.selectedRoles.options[indices[i]]);
				this.availableRoles.insertBefore(option, this.availableRoles.options[0]);
			}
		}
		this.updateButtonState();
		if (dojo.isIE && dojo.isIE > 6) {
			this.availableRoles.style.display = "block";	
		}
	},
	
	handleUp: function (e) {
		dojo.stopEvent(e);
		if (dojo.isIE) {
			this.selectedRoles.style.display = "none";
		}
		var index = getSelectedIndices(this.selectedRoles)[0];
		var option = this.selectedRoles.options[index];
		this.selectedRoles.removeChild(this.selectedRoles.options[index]);
		this.selectedRoles.insertBefore(option, this.selectedRoles.options[index - 1]);
		if (dojo.isIE && dojo.isIE < 7) {
			this.selectedRoles.selectedIndex = index - 1;
		}
		this.updateButtonState();
		if (dojo.isIE) {
			this.selectedRoles.style.display = "block";	
		}
	},
	
	handleDown: function (e) {
		dojo.stopEvent(e);
		if (dojo.isIE) {
			this.selectedRoles.style.display = "none";
		}
		var index = getSelectedIndices(this.selectedRoles)[0];
		var option = this.selectedRoles.options[index];
		this.selectedRoles.removeChild(this.selectedRoles.options[index]);
		this.selectedRoles.insertBefore(option, this.selectedRoles.options[index + 1]);
		if (dojo.isIE && dojo.isIE < 7) {
			this.selectedRoles.selectedIndex = index + 1
		}
		this.updateButtonState();
		if (dojo.isIE) {
			this.selectedRoles.style.display = "block";	
		}
	},
	
	getChosenRoles: function (e) {
		var roles = new Array();
		for (var i=0; i < this.selectedRoles.options.length; i++) {
			var option = this.selectedRoles.options[i];
			roles.push({
				id: option.value,
				description: option.description
			});
		}
		return roles;
	},
	
	updateButtonState: function () {
		var availableIndices = getSelectedIndices(this.availableRoles);
		var selectedIndices = getSelectedIndices(this.selectedRoles);
		this.addButton.disabled = availableIndices.length == 0;
		this.removeButton.disabled = selectedIndices.length == 0 || this.selectedRoles.options[this.selectedRoles.options.length - 1].selected;
		if (selectedIndices.length == 1) {
			this.upButton.disabled = selectedIndices[0] == 0 || this.selectedRoles.options[selectedIndices[0]].frozen;
			this.downButton.disabled = selectedIndices[0] == this.selectedRoles.options.length - 2 || this.selectedRoles.options[selectedIndices[0]].frozen;
		}
		else {
			this.upButton.disabled = true;
			this.downButton.disabled = true;
		}
	}
});

})();